# Strings Analytics


| Code | Language | Translated | Remaining |
|----|-------|-------|---|
| en | English [English] | 490 | 0 |
| ar | Arabic [العربية] | 490 | NULL |
| az | Azerbaijan [Azərbaycan] | 490 | NULL |
| bn | Bengali [বাংলা] | 490 | NULL |
| cn | Chinese [简体中文] | 490 | NULL |
| es | Spanish [Español] | 490 | NULL |
| fa | Persian [Farsi] | 491 | -1 |
| fr | French [Français] | 490 | NULL |
| gu | Gujarati [ગુજરાતી] | 490 | NULL |
| hi | Hindi [हिंदी] | 490 | NULL |
| id | Indonesia [Indonesia] | 490 | NULL |
| it | Italian [italiano] | 490 | NULL |
| jp | Japanese [日本] | 490 | NULL |
| ka | Kannada [ಕನ್ನಡ] | 490 | NULL |
| ml | Malayalam [മലയാളം] | 490 | NULL |
| mr | Marathi [मराठी] | 491 | -1 |
| my | Malay [Bahasa Melayu] | 490 | NULL |
| or | Odia [ଓଡିଆ] | 490 | NULL |
| pt-br | Português [Português] | 490 | NULL |
| ru | Russian [Русский] | 490 | NULL |
| si | sinhala [සිංහල] | 490 | NULL |
| ta | தமிழ் [தமிழ்] | 490 | NULL |
| tr | Turkish [Türk] | 490 | NULL |
| uz | Uzbekcha [Uzbekcha] | 490 | NULL |


If Strings are not present, Google Translation will be used to Translate them at time of Usage.